@@ -47,7 +47,7 @@ exports.serve = function (nylon_path, port) {
         cluster.on('exit', (worker, code, signal) => {
             console.log("code::"+code);
             console.log("signal::"+signal);
-            if(code!="^C" || code!=0){
+            if(signal!="SIGINT"){
                 cluster.fork();
                 logger.info('worker ' + worker.process.pid + ' died');
             }
